@@ -1,19 +1,25 @@
+{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE TemplateHaskell   #-}
+
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE PolyKinds         #-}
+#endif
+
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Control.Applicative
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Monomorphic 'TextShow' functions for 'Const' and 'ZipList'.
+'TextShow' instances for 'Const' and 'ZipList'.
 
 /Since: 2/
 -}
-module TextShow.Control.Applicative (liftShowbConstPrec, liftShowbZipListPrec) where
+module TextShow.Control.Applicative () where
 
 import Control.Applicative (Const(..), ZipList)
 
@@ -24,26 +30,23 @@ import TextShow.Classes (TextShow(..), TextShow1(..),
 import TextShow.Data.List ()
 import TextShow.TH.Internal (deriveTextShow, deriveTextShow1)
 
--- | Convert a 'Const' value to a 'Builder' with the given show function and precedence.
---
--- /Since: 3/
-liftShowbConstPrec :: (Int -> a -> Builder) -> Int -> Const a b -> Builder
-liftShowbConstPrec sp = liftShowbPrec2 sp undefined undefined undefined
-
--- | Convert a 'ZipList' to a 'Builder' with the given show function and precedence.
---
--- /Since: 3/
-liftShowbZipListPrec :: ([a] -> Builder) -> Int -> ZipList a -> Builder
-liftShowbZipListPrec sl = liftShowbPrec undefined sl
-
+-- | /Since: 2/
 instance TextShow a => TextShow (Const a b) where
-    showbPrec = liftShowbPrec undefined undefined
+    showbPrec = liftShowbConstPrec showbPrec
 
+-- | /Since: 2/
 instance TextShow a => TextShow1 (Const a) where
-    liftShowbPrec = liftShowbPrec2 showbPrec showbList
+    liftShowbPrec _ _ = liftShowbConstPrec showbPrec
 
+-- | /Since: 2/
 instance TextShow2 Const where
-    liftShowbPrec2 sp1 _ _ _ p (Const x) = showbUnaryWith sp1 "Const" p x
+    liftShowbPrec2 sp _ _ _  = liftShowbConstPrec sp
 
+liftShowbConstPrec :: (Int -> a -> Builder) -> Int -> Const a b -> Builder
+liftShowbConstPrec sp p (Const x) = showbUnaryWith sp "Const" p x
+{-# INLINE liftShowbConstPrec #-}
+
+-- | /Since: 2/
 $(deriveTextShow  ''ZipList)
+-- | /Since: 2/
 $(deriveTextShow1 ''ZipList)
