@@ -32,16 +32,6 @@ import TextShow.Data.Integral ()
 import TextShow.TH.Internal (deriveTextShow, deriveTextShow1, makeShowbPrec,
                              makeLiftShowbPrec, makeLiftShowbPrec2)
 
-#if !(MIN_VERSION_template_haskell(2,7,0))
-import Data.Monoid.Compat ((<>))
-import Data.Text.Lazy.Builder (singleton)
-
-import GHC.Exts (Char(C#), Double(D#), Float(F#), Int(I#), Word(W#))
-import GHC.Show (appPrec)
-
-import TextShow.Classes (showbParen)
-#endif
-
 -- | /Since: 2/
 instance TextShow (U1 p) where
     showbPrec = liftShowbPrec undefined undefined
@@ -94,7 +84,6 @@ instance TextShow (f (g p)) => TextShow ((f :.: g) p) where
 -- | /Since: 2/
 $(deriveTextShow1 ''(:.:))
 
-#if MIN_VERSION_template_haskell(2,7,0)
 -- | /Since: 2.1.2/
 instance TextShow (UChar p) where
     showbPrec = $(makeShowbPrec 'UChar)
@@ -124,57 +113,6 @@ instance TextShow (UWord p) where
     showbPrec = $(makeShowbPrec 'UWord)
 -- | /Since: 2.1.2/
 $(deriveTextShow1 'UWord)
-#else
--- | /Since: 2.1.2/
-instance TextShow (UChar p) where
-    showbPrec = liftShowbPrec undefined undefined
--- | /Since: 2.1.2/
-instance TextShow1 UChar where
-    liftShowbPrec _ _ p (UChar c) = showbParen (p > appPrec) $
-           "UChar "    <> singleton '{'
-        <> "uChar# = " <> showb (C# c)
-        <> singleton '}'
-
--- | /Since: 2.1.2/
-instance TextShow (UDouble p) where
-    showbPrec = liftShowbPrec undefined undefined
--- | /Since: 2.1.2/
-instance TextShow1 UDouble where
-    liftShowbPrec _ _ p (UDouble d) = showbParen (p > appPrec) $
-           "UDouble "    <> singleton '{'
-        <> "uDouble# = " <> showb (D# d)
-        <> singleton '}'
-
--- | /Since: 2.1.2/
-instance TextShow (UFloat p) where
-    showbPrec = liftShowbPrec undefined undefined
--- | /Since: 2.1.2/
-instance TextShow1 UFloat where
-    liftShowbPrec _ _ p (UFloat f) = showbParen (p > appPrec) $
-           "UFloat "    <> singleton '{'
-        <> "uFloat# = " <> showb (F# f)
-        <> singleton '}'
-
--- | /Since: 2.1.2/
-instance TextShow (UInt p) where
-    showbPrec = liftShowbPrec undefined undefined
--- | /Since: 2.1.2/
-instance TextShow1 UInt where
-    liftShowbPrec _ _ p (UInt i) = showbParen (p > appPrec) $
-           "UInt "    <> singleton '{'
-        <> "uInt# = " <> showb (I# i)
-        <> singleton '}'
-
--- | /Since: 2.1.2/
-instance TextShow (UWord p) where
-    showbPrec = liftShowbPrec undefined undefined
--- | /Since: 2.1.2/
-instance TextShow1 UWord where
-    liftShowbPrec _ _ p (UWord w) = showbParen (p > appPrec) $
-           "UWord "    <> singleton '{'
-        <> "uWord# = " <> showb (W# w)
-        <> singleton '}'
-#endif
 
 -- | /Since: 2/
 $(deriveTextShow ''Fixity)
