@@ -1,12 +1,9 @@
 {-# LANGUAGE CPP                #-}
 {-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveGeneric      #-}
 {-# LANGUAGE TemplateHaskell    #-}
 {-# LANGUAGE TypeFamilies       #-}
 
-#if __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE DeriveGeneric      #-}
-#endif
-
 #if __GLASGOW_HASKELL__ >= 706
 {-# LANGUAGE DataKinds          #-}
 {-# LANGUAGE PolyKinds          #-}
@@ -21,7 +18,7 @@
 #endif
 
 {-|
-Module:      TextShow.FromStringTextShow
+Module:      TextShow.Options
 Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
@@ -37,30 +34,34 @@ module TextShow.Options (Options(..), GenTextMethods(..), defaultOptions) where
 import           Data.Data (Data, Typeable)
 import           Data.Ix (Ix)
 
-#if __GLASGOW_HASKELL__ >= 702
 import           GHC.Generics (Generic)
-#else
-import qualified Generics.Deriving.TH as Generics
-#endif
 
 import           Language.Haskell.TH.Lift
 
 -- | Options that specify how to derive 'TextShow' instances using Template Haskell.
 --
 -- /Since: 3.4/
-newtype Options = Options
+data Options = Options
   { genTextMethods :: GenTextMethods
     -- ^ When Template Haskell should generate definitions for methods which
     --   return @Text@?
+    --
+    --   /Since: 3.4/
+  , emptyCaseBehavior :: Bool
+    -- ^ If 'True', derived instances for empty data types (i.e., ones with
+    --   no data constructors) will use the @EmptyCase@ language extension.
+    --   If 'False', derived instances will simply use 'seq' instead.
+    --   (This has no effect on GHCs before 7.8, since @EmptyCase@ is only
+    --   available in 7.8 or later.)
+    --
+    --   /Since: 3.7/
   } deriving ( Data
              , Eq
+             , Generic
              , Ord
              , Read
              , Show
              , Typeable
-#if __GLASGOW_HASKELL__ >= 702
-             , Generic
-#endif
 #if __GLASGOW_HASKELL__ >= 800
              , Lift
 #endif
@@ -78,14 +79,12 @@ data GenTextMethods
            , Data
            , Enum
            , Eq
+           , Generic
            , Ix
            , Ord
            , Read
            , Show
            , Typeable
-#if __GLASGOW_HASKELL__ >= 702
-           , Generic
-#endif
 #if __GLASGOW_HASKELL__ >= 800
            , Lift
 #endif
@@ -95,15 +94,13 @@ data GenTextMethods
 --
 -- /Since: 3.4/
 defaultOptions :: Options
-defaultOptions = Options { genTextMethods = SometimesTextMethods }
+defaultOptions =
+  Options { genTextMethods    = SometimesTextMethods
+          , emptyCaseBehavior = False
+          }
 
 -------------------------------------------------------------------------------
 
-#if __GLASGOW_HASKELL__ < 702
-$(Generics.deriveAll ''Options)
-$(Generics.deriveAll ''GenTextMethods)
-#endif
-
 #if __GLASGOW_HASKELL__ < 800
 $(deriveLift ''Options)
 $(deriveLift ''GenTextMethods)
