@@ -10,7 +10,7 @@
 
 {-|
 Module:      Instances.Data.Type.Equality
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -21,13 +21,18 @@ Portability: GHC
 module Instances.Data.Type.Equality () where
 
 #if MIN_VERSION_base(4,7,0)
-import Data.Type.Equality ((:~:)(..))
+import Data.Type.Equality ((:~:))
+# if MIN_VERSION_base(4,10,0)
+import Data.Type.Equality ((:~~:), type (~~))
+# endif
 
-import Prelude ()
-import Prelude.Compat
-
-import Test.QuickCheck (Arbitrary(..))
+import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum)
 
 instance a ~ b => Arbitrary (a :~: b) where
-    arbitrary = pure Refl
+    arbitrary = arbitraryBoundedEnum
+
+# if MIN_VERSION_base(4,10,0)
+instance a ~~ b => Arbitrary (a :~~: b) where
+    arbitrary = arbitraryBoundedEnum
+# endif
 #endif
