@@ -3,7 +3,7 @@
 
 {-|
 Module:      Spec.Data.Type.EqualitySpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -21,22 +21,28 @@ import Prelude.Compat
 import Test.Hspec (Spec, hspec, parallel)
 
 #if MIN_VERSION_base(4,7,0)
+import Data.Proxy (Proxy(..))
 import Data.Type.Equality ((:~:))
+# if MIN_VERSION_base(4,10,0)
+import Data.Type.Equality ((:~~:))
+# endif
 
-import Spec.Utils (prop_matchesTextShow)
-
+import Spec.Utils (matchesTextShowSpec)
 import Test.Hspec (describe)
-import Test.Hspec.QuickCheck (prop)
 #endif
 
 main :: IO ()
 main = hspec spec
 
 spec :: Spec
-spec = parallel $
+spec = parallel $ do
 #if MIN_VERSION_base(4,7,0)
     describe "Int :~: Int" $
-        prop "TextShow instance" (prop_matchesTextShow :: Int -> Int :~: Int -> Bool)
+        matchesTextShowSpec (Proxy :: Proxy (Int :~: Int))
+# if MIN_VERSION_base(4,10,0)
+    describe "Int :~~: Int" $
+        matchesTextShowSpec (Proxy :: Proxy (Int :~~: Int))
+# endif
 #else
     pure ()
 #endif
